OC.L10N.register(
    "notes",
    {
    "Notes" : "Notas",
    "The last viewed note cannot be accessed. " : "No se puede acceder a la última nota consultada. ",
    "Error" : "Error",
    "New note" : "Nota nueva",
    "Distraction-free notes and writing" : "Notas y escritura libre de distracciones",
    "Settings" : "Configuraciones ",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Hay notas sin salvar. ¡Al salir de la página perderá todos los cambios!",
    "All notes" : "Todas las notas",
    "Categories" : "Categorías",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "This week" : "Esta semana",
    "This month" : "Este mes",
    "Rename" : "Renombrar",
    "Delete note" : "Borrar nota",
    "Remove from favorites" : "Eliminar de favoritos",
    "Add to favorites" : "Agregar a favoritos",
    "Details" : "Detalles",
    "Preview" : "Previsualizar",
    "Edit" : "Editar",
    "Category" : "Categoría",
    "Uncategorized" : "Sin categoría",
    "Saving failed!" : "¡Falla al guardar!",
    "_%n word_::_%n words_" : ["%n palabra","%n palabras"],
    "Android app" : "Aplicación Android",
    "iOS app" : "Aplicación iOS"
},
"nplurals=2; plural=(n != 1);");
